@@ -28,11 +28,12 @@ import java.io.IOException;
 import jdk.internal.org.jline.terminal.Attributes;
 import jdk.internal.org.jline.terminal.Size;
 import jdk.internal.org.jline.terminal.impl.jna.osx.OsXNativePty;
+import jdk.internal.org.jline.terminal.spi.SystemStream;
 import jdk.internal.org.jline.terminal.spi.TerminalProvider;
 
 class JDKNativePty {
 
-    static JnaNativePty current(TerminalProvider.Stream console) throws IOException {
+    static JnaNativePty current(SystemStream console) throws IOException {
         return OsXNativePty.current(console);
     }
 
